@@ -4,8 +4,10 @@ from eksi.eksi import Eksi
 
 
 def main():
-    parser = argparse.ArgumentParser(description="Komut satırında Ekşi Sözlük!")
-    parser.add_argument("-v", "--versiyon", action="version", version="0.2.0")
+    parser = argparse.ArgumentParser(
+        description="Komut satırında Ekşi Sözlük!"
+    )
+    parser.add_argument("-v", "--versiyon", action="version", version="0.3.0")
     parser.add_argument(
         "-b",
         "--baslik",
